==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-runner/lxqt-runner_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation>Ρυθμίσεις εκτελεστή LXQt</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Ρυθμίσεις εκτελεστή</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Θέση:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Εμφάνιση σε:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Συντόμευση:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Επάνω άκρη της οθόνης</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Κέντρο της οθόνης</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Οθόνη όπου βρίσκεται το ποντίκι</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Πάντα στην οθόνη %1</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Άνω άκρο της οθόνης</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>Κέντρο της οθόνης</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Ενεργή οθόνη</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Πάντα στην οθόνη «%1»</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Επαναφορά</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Εκτέλεση εφαρμογών </translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation>Διαμόρφωση του εκτελεστή lxqt-runner</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation>Εκκαθάριση του ιστορικού του εκτελεστή lxqt-runner</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Πιέστε «%1» για εμφάνιση του διαλόγου.</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="93"/>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="97"/>
        <source>Clear History</source>
        <translation>Εκκαθάριση του ιστορικού</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="349"/>
        <source>Show/hide runner dialog</source>
        <translation>Εμφάνιση/απόκρυψη του διαλόγου του εκτελεστή</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="443"/>
        <source>History</source>
        <translation>Ιστορικό</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="801"/>
        <source>Mathematics</source>
        <translation>Μαθηματικά</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation>Διαχείριση ενέργειας του LXQt</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-runner/lxqt-runner_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>LXQt-runner Settings</source>
        <translation type="vanished">Ρυθμίσεις εκτελεστή LXQt</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Ρυθμίσεις εκτελεστή</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Θέση:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Εμφάνιση σε:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Εμφάνιση του ιστορικού πρώτα</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Αποθήκευση/Εμφάνιση ιστορικού</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Σημείωση&lt;/b&gt;: Το μέγεθος των γραφικών συστατικών ανώτατου επιπέδου περιορίζεται στα 2/3 του ύψους και πλάτους της επιφάνειας εργασίας.</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Εμφάνιση της λίστας με:</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> αντικείμενο(α)</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Συντόμευση:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation type="vanished">Επάνω άκρη της οθόνης</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation type="vanished">Κέντρο της οθόνης</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation type="vanished">Οθόνη όπου βρίσκεται το ποντίκι</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation type="vanished">Πάντα στην οθόνη %1</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Άνω άκρο της οθόνης</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>Κέντρο της οθόνης</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Ενεργή οθόνη</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Πάντα στην οθόνη «%1»</translation>
    </message>
    <message>
        <location filename="../../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Επαναφορά</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Εκτέλεση εφαρμογών </translation>
    </message>
    <message>
        <source>Configure lxqt-runner</source>
        <translation type="vanished">Διαμόρφωση του εκτελεστή lxqt-runner</translation>
    </message>
    <message>
        <source>Clear lxqt-runner History</source>
        <translation type="vanished">Εκκαθάριση του ιστορικού του εκτελεστή lxqt-runner</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation type="vanished">Πιέστε «%1» για εμφάνιση του διαλόγου.</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="93"/>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="97"/>
        <source>Clear History</source>
        <translation>Εκκαθάριση του ιστορικού</translation>
    </message>
    <message>
        <location filename="../../dialog.cpp" line="350"/>
        <source>Show/hide runner dialog</source>
        <translation>Εμφάνιση/απόκρυψη του διαλόγου του εκτελεστή</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../providers.cpp" line="444"/>
        <source>History</source>
        <translation>Ιστορικό</translation>
    </message>
    <message>
        <location filename="../../providers.cpp" line="823"/>
        <source>Mathematics</source>
        <translation>Μαθηματικά</translation>
    </message>
    <message>
        <source>LXQt Power Management</source>
        <translation type="vanished">Διαχείριση ενέργειας του LXQt</translation>
    </message>
</context>
</TS>
